"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _map2 = require("lodash/map");

var _map3 = _interopRequireDefault(_map2);

exports.MapTypeControl = MapTypeControl;

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _propTypes = require("prop-types");

var _propTypes2 = _interopRequireDefault(_propTypes);

var _Control = require("./Control");

var _MapContext = require("../internal/MapContext");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Controls display options Map type control.
 *
 * **Usage:**
 *
 * ```javascript
 * import React from "react";
 * import { GoogleMap, MapTypeControl } from "react-google-map-components"
 *
 * export default function GoogleMapWrapper(props) {
 *   return (
 *     <GoogleMap {...props} maps={google.maps}>
 *       <MapTypeControl />
 *     </GoogleMap>
 *   );
 * }
 * ```
 *
 * **Google Maps Docs:**
 * * [google.maps.MapTypeControlOptions](https://developers.google.com/maps/documentation/javascript/reference#MapTypeControlOptions)
 */
function MapTypeControl(props, context) {
  var mapContext = context.mapContext;


  return _react2.default.createElement(_Control.Control, {
    name: "mapTypeControl",
    options: {
      position: mapContext.getEnum("ControlPosition", props.position),
      style: mapContext.getEnum("MapTypeControlStyle", props.controlStyle),
      mapTypeIds: (0, _map3.default)(props.mapTypeIds, function (x) {
        return mapContext.getEnum("MapTypeId", x);
      })
    }
  });
}

MapTypeControl.contextTypes = {
  mapContext: _propTypes2.default.instanceOf(_MapContext.MapContext).isRequired
};

MapTypeControl.defaultProps = {
  position: "TOP_RIGHT",
  controlStyle: "DEFAULT",
  mapTypeIds: ["HYBRID", "ROADMAP", "SATELLITE", "TERRAIN"]
};

/* istanbul ignore else */
if (process.env.NODE_ENV !== "production") {
  MapTypeControl.propTypes = {
    /**
     * Position id.
     *
     * Used to specify the position of the control on the map.
     *
     * See also: [google.maps.ControlPosition](https://developers.google.com/maps/documentation/javascript/reference#ControlPosition)
     */
    position: _propTypes2.default.oneOf(["BOTTOM_CENTER", "BOTTOM_LEFT", "BOTTOM_RIGHT", "LEFT_BOTTOM", "LEFT_CENTER", "LEFT_TOP", "RIGHT_BOTTOM", "RIGHT_CENTER", "RIGHT_TOP", "TOP_CENTER", "TOP_LEFT", "TOP_RIGHT"]),

    /**
     * Style id.
     *
     * Used to select what style of map type control to display.
     *
     * See also: [google.maps.MapTypeControlStyle](https://developers.google.com/maps/documentation/javascript/reference#MapTypeControlStyle)
     */
    controlStyle: _propTypes2.default.oneOf(["DEFAULT", "DROPDOWN_MENU", "HORIZONTAL_BAR"]),

    /**
     * IDs of map types to show in the control.
     *
     * See also: [google.maps.MapTypeId](https://developers.google.com/maps/documentation/javascript/reference#MapTypeId)
     */
    mapTypeIds: _propTypes2.default.arrayOf(_propTypes2.default.oneOf(["HYBRID", "ROADMAP", "SATELLITE", "TERRAIN"]))
  };
}